@@ -37,7 +37,7 @@ use constant {
     TOP_LABEL_HEIGHT    => 2,
 };
 
-my $VERSION = "0.97";
+my $VERSION = "0.98";
 
 my %opts = (
     cache_dir   => "/var/lib/sysv-rc-conf",
@@ -407,7 +407,7 @@ sub runlevel_status
     while ( defined(my $service = readdir INITD) ) {
 	next if $service =~ /\.sh$/; # see the debian policy manual
 	next if $service =~ /^\.+$/; # ignore . and ..
-	next unless -x $service;     # ignore stuff like README
+	next unless -x "$initd/$service"; # ignore stuff like README
 	$runlevels{$service} = { };
     }
     closedir INITD or die "$0: closedir $initd : $!";
